import os
from pathlib import Path

DEFAULT_VAULT_DIR = Path.home() / ".pm"
DEFAULT_VAULT_PATH = DEFAULT_VAULT_DIR / "vault.db"


def get_vault_path() -> Path:
    return Path(os.environ.get("PM_VAULT_PATH", str(DEFAULT_VAULT_PATH)))
